/**
 * Università della Calabria COLORS
 */
a {
  color: #396;
}
a:hover, a:active {
  color: #383838;
}
a.read-more {
  color: #9d9d9c;
}
.badge-primary {
  background: #396;
}
.badge-secondary {
  background: #383838;
}
.btn-primary {
  background: #383838;
}
.btn-primary:hover {
  background: #9d9d9c;
}
.btn-outline-primary, .btn-outline-primary:visited {
  color: #383838;
  -webkit-box-shadow: inset 0 0 0 1px #383838;
  box-shadow: inset 0 0 0 1px #383838;
}
.btn-outline-primary:hover {
  color: #9d9d9c;
  -webkit-box-shadow: inset 0 0 0 1px #9d9d9c;
  box-shadow: inset 0 0 0 1px #9d9d9c;
}
.btn-outline-primary:active, .btn-outline-primary:focus {
  color: #383838 !important;
  box-shadow: inset 0 1px 0 #9d9d9c, 0 1px 1px #9d9d9c, 0 0 0 0.2rem rgba(101, 101, 102, 0.5) !important;
}
.btn-secondary {
  background: #396;
}
.btn-secondary:hover {
  background: #383838;
}
.btn:not(.btn-outline-primary):not(.btn-outline-secondary):active, .btn:not(.btn-outline-primary):not(.btn-outline-secondary):focus {
  box-shadow: inset 0 1px 0 rgba(255, 255, 255, 0.15), 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 0 0.2rem rgba(101, 101, 102, 0.5) !important;
  background-color: #475664 !important;
}
.text-primary {
  color: #383838 !important;
}
.text-secondary {
  color: #396 !important;
}
/**
 * Header Slim Wrapper
 */
.it-header-slim-wrapper {
  background: #396;
}
.it-header-slim-wrapper .it-header-slim-wrapper-content .header-slim-right-zone button {
  background: #383838;
}
.it-header-slim-wrapper .it-header-slim-wrapper-content .header-slim-right-zone button:hover {
  background: #9d9d9c;
  color: #383838;
}
.it-header-center-wrapper {
  background: #ffffff;
}
.it-header-center-wrapper .it-header-center-content-wrapper .it-brand-wrapper a, .it-header-center-wrapper .it-header-center-content-wrapper .it-right-zone {
  color: #383838;
}
.it-header-center-wrapper .it-header-center-content-wrapper .it-right-zone .it-socials ul .icon, .it-header-center-wrapper .it-header-center-content-wrapper .it-search-wrapper a.rounded-icon svg {
  fill: #383838;
}
/**
 * Header Navbar Wrapper
 */
/* Desktops and laptops ----------- */
@media (min-width: 992px) {
  .it-header-navbar-wrapper {
    background: #383838;
  }
}
/* Others than desktop ----------- */
@media (max-width: 991px) {
  .it-header-navbar-wrapper {
    background: none;
  }
  .custom-navbar-toggler svg {
    fill: #383838;
  }
}
/**
 * Footer Main
 */
.it-footer-main {
  background: #396;
}
/**
 * Footer Small Prints
 */
.it-footer-small-prints {
  background: #396;
}
/**
 * Carousel
 */
.it-carousel-wrapper .owl-dots .owl-dot {
  background: #383838;
}
/**
 * Back to top
 */
.back-to-top {
  background: #9d9d9c;
}
.back-to-top:hover {
  background: #383838;
}
/**
 * Form Bootstrap Italia
 */
.toggles label input[type="checkbox"]:checked + .lever::after {
  background-color: #396;
}
.form-check [type=radio]:checked + label::after, .form-check [type=checkbox]:checked + label::after {
  background-color: #396;
  border-color: #396;
}
.form-check [type=radio]:checked + label::before {
  border-color: #396;
}
/**
 * Section muted
 */
.section.section-muted {
  background-color: #f7f7f7;
}
a {
  color: #B01717;
}
a:hover, a:active {
  color: #6f0b0a;
}
/** only visited **/
a.no-color, ol.breadcrumb a {
  color: #383838;
}
.background-yellow {
  background: #ffed00;
}
.background-white {
  background: #ffffff;
}
.background-light-grey {
  background: #e3e9ec;
  color: #383838;
}
.icon-light {
  fill: #fff !important;
}
.dark-grey-background {
  background: #d3d2cf;
}
.it-header-center-wrapper {
  background: #396;
}
.it-header-center-wrapper .it-header-center-content-wrapper .it-right-zone {
  color: #fff;
}
input.top-input {
  background: none;
  border: 1px solid #fff;
  color: #ffffff;
}
.it-hero-wrapper .it-hero-text-wrapper h1 {
  background: #fff;
  color: #383838;
}
.it-hero-wrapper.it-overlay.it-dark .img-responsive-wrapper:after {
  background: none;
}
.section-title-label {
  background: #fff;
}
.card .etichetta {
  color: #176fc1;
}
.btn-grey-presta {
  background: #d3d2cf;
}
.btn-grey-presta:hover {
  color: #ffffff;
  background: #383838;
}
.bg-dark .btn-secondary {
  background: #396;
}
.bg-dark .btn-secondary:hover {
  background: #383838;
}
.it-right-zone .nav-link {
  color: #ffffff;
}
@media (max-width: 991px) {
  .custom-navbar-toggler svg {
    fill: #ffffff;
  }
}
.it-header-slim-wrapper {
  background: #00f;
  border-bottom: 1px solid #fff;
}
.badge-grey-unical {
  background: #e3e9ec;
  color: #383838;
}
a .badge-grey-unical:hover, a .badge-grey-unical.selected {
  background: #383838;
  color: #e3e9ec;
}
.breadcrumb-container {
  border-top: 2px solid #396;
  border-bottom: 2px solid #396;
}
@media (min-width: 992px) {
  .it-header-navbar-wrapper {
    background: #ffffff;
  }
}
.it-hero-wrapper {
  background-color: #fff !important;
}
.bordeaux-unical-bg {
  background: #396;
}
.bordeaux-unical-color {
  color: #396;
}
.white-unical-color {
  color: #ffffff;
}
.accordion-header [data-bs-toggle=collapse][aria-expanded=false], .accordion-header [data-bs-toggle=collapse]:before {
  color: #383838;
}
.accordion-header {
  border-color: #e3e4e6 !important;
}
.nav-tabs .nav-link, .nav-tabs .nav-link:hover {
  color: #9d9d9c;
}
.nav-tabs .nav-item.show .nav-link, .nav-tabs .nav-link.active {
  border-bottom-color: #396;
  color: #383838;
}
.link-list-wrapper ul li a span, .link-list-wrapper ul li a:hover:not(.disabled) span {
  color: #383838;
}
.card .card-body a h5.card-title {
  color: #383838;
}
.progress-spinner.progress-spinner-double .progress-spinner-inner:after {
  border: 4px solid #396;
  border-right: 4px solid transparent;
  border-bottom: 4px solid transparent;
}
figure.table tr:nth-of-type(2n) {
  background-color: #f6f7f9;
}
.progress {
  background-color: #e3e9ec;
}
.progress-bar {
  background-color: #396;
}
.it-footer-small-prints {
  border-top: 1px solid #fff;
}
.it-hero-wrapper .it-hero-text-wrapper h5.unical-hero-preheading {
  background: #396;
  color: #fff;
}
.it-hero-wrapper .it-hero-text-wrapper h6.unical-hero-preheading {
  background: #396;
  color: #fff;
}
.it-hero-wrapper .it-hero-text-wrapper h1.unical-hero-heading, .it-hero-wrapper .it-hero-text-wrapper h2.unical-hero-heading, .it-hero-wrapper .it-hero-text-wrapper h3.unical-hero-heading, .it-hero-wrapper .it-hero-text-wrapper h4.unical-hero-heading {
  background: #fff;
  color: #396;
}
.it-footer-main h4 a {
  border-bottom: 1px solid #396;
}
input.top-input::placeholder {
  color: #fff;
}
